
function loadPlayer()
	player = {}

	playerStill = love.graphics.newImage("Sprites/Char1Still.png")
	player.pic = playerStill

	player.x = love.graphics.getWidth() / 2
	player.y = 825 - (5 * player.pic:getHeight())
	player.width = player.pic:getWidth() * worldScale
	player.height = player.pic:getHeight() * worldScale

	rightAnimation = newAnimation(love.graphics.newImage("Sprites/Char1Right.png"), 13, 17, 0.5)
	leftAnimation = newAnimation(love.graphics.newImage("Sprites/Char1Left.png"), 13, 17, 0.5)

	player.ground = player.y
	player.xvel = 0
	player.yvel = 0
	player.jumpHeight = -300
	player.gravity = -800
end

function drawPlayer(direction) 
	love.graphics.setColor(255, 255, 255)
	if player.direction == "R" then
		local spriteNum = math.floor(rightAnimation.currentTime / rightAnimation.duration * #rightAnimation.quads) + 1
   		love.graphics.draw(rightAnimation.spriteSheet, rightAnimation.quads[spriteNum],player.x,player.y,0,worldScale)
   	end
   	if player.direction == "L" then
		local spriteNum = math.floor( leftAnimation.currentTime /  leftAnimation.duration * # leftAnimation.quads) + 1
   		love.graphics.draw( leftAnimation.spriteSheet,  leftAnimation.quads[spriteNum],player.x,player.y,0,worldScale)
   	end
   	if player.direction == "N" then
   		love.graphics.draw(playerStill, player.x,player.y,0,worldScale)
   	end
end

function updatePlayer(dt)
	vMovement(dt)
	hMovement(dt)

	if love.keyboard.isDown("e") then
		newProjectile(player.x, player.y, 0, arrow)
	end

	player.x = player.x + player.xvel * dt
	player.y = player.y + player.yvel * dt

	camera:move(player.xvel * dt, 0)
end	

function hMovement(dt,bool)
	if love.keyboard.isDown("d") and not love.keyboard.isDown("a") then
		if player.x < (window.width - player.pic:getWidth() * 5) then
			if player.xvel <= 200 then
				player.xvel = player.xvel + 5
			end
		else
			player.xvel = 0
		end
	end
	if love.keyboard.isDown("a") and not love.keyboard.isDown("d") then
		if player.x > 0 then
			if player.xvel >= -200 then
				player.xvel = player.xvel - 5
			end
		else
			player.xvel = 0
		end
	end
	if (not love.keyboard.isDown("a") and not love.keyboard.isDown("d")) or (love.keyboard.isDown("a") and love.keyboard.isDown("d")) then
		if player.xvel > 10 then
			player.xvel = player.xvel - 30
		elseif player.xvel < -10 then
			player.xvel = player.xvel + 30
		elseif player.xvel > -10 or player.xvel < 10 then
			player.xvel = 0 
		end
	end
	-- Detection
	if player.xvel > 0 then
		player.direction = "R"
	elseif player.xvel < 0  then
		player.direction = "L"
	elseif player.xvel == 0 then
		player.direction = "N"
	end
end

function vMovement(dt,bool)
	if love.keyboard.isDown("space") or love.keyboard.isDown("w") then
		if player.yvel == 0 then
			player.yvel = player.jumpHeight
		end
	end
	if player.y > player.ground then
		player.yvel = 0 
		player.y = player.ground
	end
	-- Gravity
	if player.yvel ~= 0 then
		player.yvel = player.yvel - player.gravity * dt
	end
end

function updateAnimation(dt)
	rightAnimation.currentTime = rightAnimation.currentTime + dt
    if rightAnimation.currentTime >= rightAnimation.duration then
        rightAnimation.currentTime = rightAnimation.currentTime - rightAnimation.duration
    end
    leftAnimation.currentTime = leftAnimation.currentTime + dt
    if leftAnimation.currentTime >= leftAnimation.duration then
        leftAnimation.currentTime = leftAnimation.currentTime - leftAnimation.duration
    end
end

function newAnimation(image, width, height, duration)
    local animation = {}
    animation.spriteSheet = image;
    animation.quads = {};

    for y = 0, image:getHeight() - height, height do
        for x = 0, image:getWidth() - width, width do
            table.insert(animation.quads, love.graphics.newQuad(x, y, width, height, image:getDimensions()))
        end
    end
 
    animation.duration = duration or 1
    animation.currentTime = 0

    return animation
end